package net.sit.dialog.cli;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.Vector;

import org.apache.log4j.Logger;
import org.apache.log4j.PropertyConfigurator;

import net.sit.dialog.cfg.Cfg;

/**
 * @author Christoph Sandhaus
 *         <p>
 *         Der Client.
 */
public class Client {

	static Logger logger = Logger.getLogger(Client.class.getName());

	private final String MESSAGES_FILE = "messages.list";

	private String serverIp;

	public Client(String serverIp) {
		this.serverIp = serverIp;
		startClient();
	}

	public void startClient() {
		String logProperties = System.getProperty("log.profile");
		Vector msgs = new Vector();

		if (logProperties == null) {
			System.err.println("\nProperty Datei fr log4j nicht gefunden"
					+ " oder sie wurde nicht angegeben.\n"
					+ "Beispielaufruf:\n"
					+ "  java -Dlog.profile=log.properties -jar ...\n");
			System.exit(1);
		} else {
			File f = new File(logProperties);
			if (!f.canRead()) {
				System.err.println("\nPropertydatei '" + f.getAbsolutePath()
						+ "' nicht gefunden.\n");
				System.exit(2);
			}
		}
		PropertyConfigurator.configure(logProperties);

		ClientRMIConnector crc = new ClientRMIConnector(serverIp);
		File messages = new File(MESSAGES_FILE);
		String txtstr;
		FileReader fr = null;
		logger.debug("lese Datei " + MESSAGES_FILE);
		if (messages.canRead()) {
			try {
				fr = new FileReader(messages);
			} catch (FileNotFoundException e) {
				System.err.println("Datei '" + MESSAGES_FILE
						+ "' mit den Nachrichtentexten nicht gefunden.");
				System.exit(5);
			}
			BufferedReader br = new BufferedReader(fr);
			logger.debug("lese zeilenweise ...");
			try {
				while ((txtstr = br.readLine()) != null) {
					if (txtstr.length() > 0) {
						logger.debug("Fge Nachricht ein: <" + txtstr + ">");
						msgs.addElement(txtstr);
					}
				}
			} catch (IOException e) {
				e.printStackTrace();
			}
		} else {
			logger.error("Kann Datei '" + messages.getAbsolutePath()
					+ "' nicht lesen");
			System.exit(6);
		}

		logger.info("Starte Client ...");
		ClientGui gui = new ClientGui(msgs, serverIp);
	}

	public static void main(String[] args) {
		if (args.length != 1) {
			System.out
					.println("\nBitte als Argument die IP Adresse des Servers angeben.\n");
			System.exit(7);
		}

		if ("-v".equals(args[0])) {
			System.out.println("\nWritten by: Christoph Sandhaus, 2005");
			System.out.println("Lizenz    : GNU Public License");
			System.out.println("Version   : " + Cfg.APP_VERSION + "\n");
			System.exit(0);
		}

		Client cl = new Client(args[0]);
	}
}