package net.sit.dialog.cli;

import java.awt.Dimension;
import java.awt.Point;

import net.sit.conf.AppSettings;
import net.sit.dialog.cfg.Cfg;

public class Config {

	/** Zugriff auf die Konfigurationsdatei */
	private AppSettings cfgFile;

	/** Klasse Config als Singleton implementieren */
	private static Config settings;

	/** Identifyer fr Frameangaben in der Konfig Datei */
	private final String FRAME = "FRAME_";

	private Config() {
		/**
		 * Zugriff auf die Konfig Datei erstellen. APP_NAME bestimmt dabei Pfad
		 * und Dateinamen zu der Datei
		 */
		cfgFile = AppSettings.Factory.getInstance(Cfg.APP_NAME);
	}

	public static synchronized Config getInstance() {
		/**
		 * Wurde die Singleton Instanz noch nicht erstellt, wird sie jetzt
		 * erzeugt
		 */
		if (settings == null) {
			settings = new Config();
		}
		return settings;
	}

	/**
	 * Liefert die Fenstergre aus der Konfigurationsdatei.
	 * 
	 * @return Dimension mit den Werten width und heigt fr die Fenstergre
	 *         (default: 250x80)
	 */
	public Dimension getFrameSize() {
		int width = Integer.parseInt(cfgFile
				.getProperty(FRAME + "WIDTH", "250"));
		int height = Integer.parseInt(cfgFile.getProperty(FRAME + "HEIGHT",
				"80"));
		return new Dimension(width, height);
	}

	/**
	 * Speichert die Fenstergre in der Konfigurationsdatei.
	 * 
	 * @param dim
	 *            Die Dimension des Fensters mit Breite und Hhe
	 */
	public void setFrameSize(Dimension dim) {
		cfgFile.setProperty(FRAME + "WIDTH", String.valueOf(dim.width));
		cfgFile.setProperty(FRAME + "HEIGHT", String.valueOf(dim.height));
		cfgFile.storeSettings();
	}
	
    /**
     * Speichern der Fensterposition
     * 
     * @param p
     *            ein Point mit der Position des Fensters
     */
    public void setFramePosition(Point p) {
        cfgFile.setProperty(FRAME + "X", String.valueOf(p.x));
        cfgFile.setProperty(FRAME + "Y", String.valueOf(p.y));
        cfgFile.storeSettings();
    }

    /**
     * Liefert die gespeicherte Fensterposition
     * 
     * @return einen Point mit den Werten x und y fr die Fensterposition
     *         (default: 0/0)
     */
    public Point getFramePosition() {
        int x = Integer.parseInt(cfgFile.getProperty(FRAME + "X", "0"));
        int y = Integer.parseInt(cfgFile.getProperty(FRAME + "Y", "0"));
        return new Point(x, y);
    }


}
